@@ -2,45 +2,46 @@ package List::MoreUtils;
 
 use 5.00503;
 use strict;
+use Exporter   ();
+use DynaLoader ();
 
-require Exporter;
-require DynaLoader;
 use vars qw($VERSION @ISA @EXPORT_OK %EXPORT_TAGS);
-@ISA = qw(Exporter DynaLoader);
-
-%EXPORT_TAGS = ( 
-    all => [ qw(any all none notall true false firstidx first_index lastidx
-		last_index insert_after insert_after_string apply after after_incl before
-		before_incl indexes firstval first_value lastval last_value each_array
-		each_arrayref pairwise natatime mesh zip uniq minmax part) ],
-);
-
-@EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
-
-$VERSION = '0.22';
+BEGIN {
+    $VERSION     = '0.24';
+    @ISA         = qw{Exporter DynaLoader};
+    %EXPORT_TAGS = ( 
+        all => [ qw{
+            any all none notall true false firstidx first_index lastidx
+            last_index insert_after insert_after_string apply after after_incl before
+            before_incl indexes firstval first_value lastval last_value each_array
+            each_arrayref pairwise natatime mesh zip uniq minmax part
+        } ],
+    );
+    @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
+}
 
 eval {
-    local $ENV{PERL_DL_NONLAZY} = 0 if $ENV{PERL_DL_NONLAZY};
+    local $ENV{PERL_DL_NONLAZY} = $ENV{PERL_DL_NONLAZY} ? 0 : $ENV{PERL_DL_NONLAZY};
     bootstrap List::MoreUtils $VERSION;
     1;
-} if not $ENV{LIST_MOREUTILS_PP};
+} unless $ENV{LIST_MOREUTILS_PP};
 
-eval <<'EOP' if not defined &any;
+eval <<'EOP' unless defined &any;
 
 sub any (&@) {
     my $f = shift;
     return if ! @_;
     for (@_) {
-	return 1 if $f->();
+        return 1 if $f->();
     }
     return 0;
 }
-    
+
 sub all (&@) {
     my $f = shift;
     return if ! @_;
     for (@_) {
-	return 0 if ! $f->();
+        return 0 if ! $f->();
     }
     return 1;
 }
@@ -49,7 +50,7 @@ sub none (&@) {
     my $f = shift;
     return if ! @_;
     for (@_) {
-	return 0 if $f->();
+        return 0 if $f->();
     }
     return 1;
 }
@@ -58,7 +59,7 @@ sub notall (&@) {
     my $f = shift;
     return if ! @_;
     for (@_) {
-	return 1 if ! $f->();
+        return 1 if ! $f->();
     }
     return 0;
 }
@@ -67,7 +68,7 @@ sub true (&@) {
     my $f = shift;
     my $count = 0;
     for (@_) {
-	$count++ if $f->();
+        $count++ if $f->();
     }
     return $count;
 }
@@ -76,7 +77,7 @@ sub false (&@) {
     my $f = shift;
     my $count = 0;
     for (@_) {
-	$count++ if ! $f->();
+        $count++ if ! $f->();
     }
     return $count;
 }
@@ -84,8 +85,8 @@ sub false (&@) {
 sub firstidx (&@) {
     my $f = shift;
     for my $i (0 .. $#_) {
-	local *_ = \$_[$i];	
-	return $i if $f->();
+        local *_ = \$_[$i];	
+        return $i if $f->();
     }
     return -1;
 }
@@ -93,8 +94,8 @@ sub firstidx (&@) {
 sub lastidx (&@) {
     my $f = shift;
     for my $i (reverse 0 .. $#_) {
-	local *_ = \$_[$i];
-	return $i if $f->();
+        local *_ = \$_[$i];
+        return $i if $f->();
     }
     return -1;
 }
@@ -104,8 +105,8 @@ sub insert_after (&$\@) {
     my $c = -1;
     local *_;
     for my $i (0 .. $#$list) {
-	$_ = $list->[$i];
-	$c = $i, last if $code->();
+        $_ = $list->[$i];
+        $c = $i, last if $code->();
     }
     @$list = (@{$list}[0..$c], $val, @{$list}[$c+1..$#$list]) and return 1 if $c != -1;
     return 0;
@@ -115,8 +116,8 @@ sub insert_after_string ($$\@) {
     my ($string, $val, $list) = @_;
     my $c = -1;
     for my $i (0 .. $#$list) {
-	local $^W = 0;
-	$c = $i, last if $string eq $list->[$i];
+        local $^W = 0;
+        $c = $i, last if $string eq $list->[$i];
     }
     @$list = (@{$list}[0..$c], $val, @{$list}[$c+1..$#$list]) and return 1 if $c != -1;
     return 0;
@@ -128,44 +129,38 @@ sub apply (&@) {
     wantarray ? @values : $values[-1];
 }
 
-sub after (&@)
-{
+sub after (&@) {
     my $test = shift;
     my $started;
     my $lag;
     grep $started ||= do { my $x=$lag; $lag=$test->(); $x},  @_;
 }
 
-sub after_incl (&@)
-{
+sub after_incl (&@) {
     my $test = shift;
     my $started;
     grep $started ||= $test->(), @_;
 }
 
-sub before (&@)
-{
+sub before (&@) {
     my $test = shift;
     my $keepgoing=1;
     grep $keepgoing &&= !$test->(),  @_;
 }
 
-sub before_incl (&@)
-{
+sub before_incl (&@) {
     my $test = shift;
     my $keepgoing=1;
     my $lag=1;
     grep $keepgoing &&= do { my $x=$lag; $lag=!$test->(); $x},  @_;
 }
 
-sub indexes (&@)
-{
+sub indexes (&@) {
     my $test = shift;
     grep {local *_=\$_[$_]; $test->()} 0..$#_;
 }
 
-sub lastval (&@)
-{
+sub lastval (&@) {
     my $test = shift;
     my $ix;
     for ($ix=$#_; $ix>=0; $ix--)
@@ -178,8 +173,7 @@ sub lastval (&@)
     return undef;
 }
 
-sub firstval (&@)
-{
+sub firstval (&@) {
     my $test = shift;
     foreach (@_)
     {
@@ -188,8 +182,7 @@ sub firstval (&@)
     return undef;
 }
 
-sub pairwise(&\@\@)
-{
+sub pairwise(&\@\@) {
     my $op = shift;
     use vars qw/@A @B/;
     local (*A, *B) = @_;    # syms for caller's input arrays
@@ -213,13 +206,11 @@ sub pairwise(&\@\@)
     }  0 .. $limit;
 }
 
-sub each_array (\@;\@\@\@\@\@\@\@\@\@\@\@\@\@\@\@\@\@\@\@\@\@\@\@\@)
-{
+sub each_array (\@;\@\@\@\@\@\@\@\@\@\@\@\@\@\@\@\@\@\@\@\@\@\@\@\@) {
     return each_arrayref(@_);
 }
 
-sub each_arrayref
-{
+sub each_arrayref {
     my @arr_list  = @_;     # The list of references to the arrays
     my $index     = 0;      # Which one the caller will get next
     my $max_num   = 0;      # Number of elements in longest array
@@ -260,8 +251,7 @@ sub each_arrayref
     }
 }
 
-sub natatime ($@)
-{
+sub natatime ($@) {
     my $n = shift;
     my @list = @_;
 
@@ -288,24 +278,24 @@ sub minmax (@) {
     my $min = my $max = $_[0];
 
     for (my $i = 1; $i < @_; $i += 2) {
-	if ($_[$i-1] <= $_[$i]) {
-	    $min = $_[$i-1] if $min > $_[$i-1];
-	    $max = $_[$i]   if $max < $_[$i];
-	} else {
-	    $min = $_[$i]   if $min > $_[$i];
-	    $max = $_[$i-1] if $max < $_[$i-1];
-	}
+        if ($_[$i-1] <= $_[$i]) {
+            $min = $_[$i-1] if $min > $_[$i-1];
+            $max = $_[$i]   if $max < $_[$i];
+        } else {
+            $min = $_[$i]   if $min > $_[$i];
+            $max = $_[$i-1] if $max < $_[$i-1];
+        }
     }
 
     if (@_ & 1) {
-	my $i = $#_;
-	if ($_[$i-1] <= $_[$i]) {
-	    $min = $_[$i-1] if $min > $_[$i-1];
-	    $max = $_[$i]   if $max < $_[$i];
-	} else {
-	    $min = $_[$i]   if $min > $_[$i];
-	    $max = $_[$i-1] if $max < $_[$i-1];
-	}
+        my $i = $#_;
+        if ($_[$i-1] <= $_[$i]) {
+            $min = $_[$i-1] if $min > $_[$i-1];
+            $max = $_[$i]   if $max < $_[$i];
+        } else {
+            $min = $_[$i]   if $min > $_[$i];
+            $max = $_[$i-1] if $max < $_[$i-1];
+        }
     }
 
     return ($min, $max);
@@ -325,25 +315,30 @@ sub _XScompiled {
 EOP
 
 *first_index = \&firstidx;
-*last_index = \&lastidx;
+*last_index  = \&lastidx;
 *first_value = \&firstval;
-*last_value = \&lastval;
-*zip = \&mesh;
+*last_value  = \&lastval;
+*zip         = \&mesh;
 
 1;
+
 __END__
 
+=pod
+
 =head1 NAME
 
 List::MoreUtils - Provide the stuff missing in List::Util
 
 =head1 SYNOPSIS
 
-    use List::MoreUtils qw(any all none notall true false firstidx first_index 
-                           lastidx last_index insert_after insert_after_string 
-                           apply after after_incl before before_incl indexes 
-                           firstval first_value lastval last_value each_array
-                           each_arrayref pairwise natatime mesh zip uniq minmax);
+    use List::MoreUtils qw(
+        any all none notall true false firstidx first_index 
+        lastidx last_index insert_after insert_after_string 
+        apply after after_incl before before_incl indexes 
+        firstval first_value lastval last_value each_array
+        each_arrayref pairwise natatime mesh zip uniq minmax
+    );
 
 =head1 DESCRIPTION
 
@@ -683,10 +678,6 @@ there for the test-suite to force testing the Perl implementation, and possibly
 for reporting of bugs. I don't see any reason to use it in a production
 environment.
 
-=head1 VERSION
-
-This is version 0.22.
-
 =head1 BUGS
 
 There is a problem with a bug in 5.6.x perls. It is a syntax error to write
@@ -785,11 +776,11 @@ L<List::Util>
 
 =head1 AUTHOR
 
-Tassilo von Parseval, E<lt>tassilo.von.parseval@rwth-aachen.deE<gt>
+Tassilo von Parseval E<lt>tassilo.von.parseval@rwth-aachen.deE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2004-2006 by Tassilo von Parseval
+Copyright 2004 - 2010 by Tassilo von Parseval
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.4 or,
